@@ -1,6 +1,6 @@
-from threading import Timer
-from typing import Callable, Hashable
 import logging
+from threading import Timer
+from typing import Callable, Dict, Hashable, Optional
 
 log = logging.getLogger(__name__)
 
@@ -38,7 +38,7 @@ class ResettableTimer:
 
     def set(
         self,
-        timeout: float,
+        timeout: Optional[float],
         handler: Callable[..., None],
         *handler_args,
         **handler_kwargs
@@ -77,7 +77,7 @@ class HysteresisHandlerIndex:
     for a period of time
     """
 
-    def __init__(self, hysteresis_duration: float = 1.0):
+    def __init__(self, hysteresis_duration: Optional[float] = 1.0):
         """Initialize the Index.
 
         Args:
@@ -86,7 +86,7 @@ class HysteresisHandlerIndex:
             Defaults to 1.0 second.
         """
         self.hysteresis_duration = hysteresis_duration
-        self.handlers = {}
+        self.handlers: Dict[Hashable, ResettableTimer] = {}
 
     def signal(
         self,
