@@ -1,18 +1,16 @@
-from fnmatch import fnmatch
-from datetime import datetime
-from os.path import isfile
-from typing import Union
-from pathlib import Path
-import re
 import logging
+import re
+from datetime import datetime
+from fnmatch import fnmatch
+from os.path import isfile
+from pathlib import Path
+from typing import List, Union
 
 from redis.exceptions import ResponseError
-
-from watchdog.observers import Observer
 from watchdog.events import PatternMatchingEventHandler
+from watchdog.observers import Observer
 
-from redgrease import client, requirements, hysteresis, formatting
-
+from redgrease import client, formatting, hysteresis, requirements
 
 log = logging.getLogger(__name__)
 
@@ -20,7 +18,7 @@ default_index_prefix = "/redgrease/scripts"
 default_script_pattern = "*.py"
 default_requirements_pattern = "*requirements*.txt"
 default_unblocking_pattern = "unblock"
-default_ignore_patterns = []
+default_ignore_patterns: List[str] = []
 
 
 def fail(exception, *messages):
@@ -46,7 +44,7 @@ class GearsLoader:
         self,
         script_pattern: str = None,
         requirements_pattern: str = None,
-        unblocking_pattern: Union[str, re.Pattern] = None,
+        unblocking_pattern=None,
         ignore_patterns: str = None,
         index_prefix: str = None,
         server: str = "localhost",
@@ -54,7 +52,7 @@ class GearsLoader:
         observe: float = None,
         **redis_kwargs,
     ):
-        self.directories = []
+        self.directories: List[Path] = []
 
         self.script_pattern = (
             script_pattern if script_pattern else default_script_pattern
